@@ -12,7 +12,7 @@ class TestFractionMethod(unittest.TestCase):
         candidates_index = [0,1,2,6,7,8,9]
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         r = 1
-        selected_feature, criterion_value, cost = fraction_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = fraction_find_best_feature(
             j_criterion_func=mim, 
             r=r,
             data=integer_matrix, 
@@ -20,6 +20,7 @@ class TestFractionMethod(unittest.TestCase):
             possible_variables_index=candidates_index,
             costs=costs)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float)
 
@@ -31,7 +32,7 @@ class TestFractionMethod(unittest.TestCase):
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         r = 1
         beta = 1
-        selected_feature, criterion_value, cost = fraction_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = fraction_find_best_feature(
                                     j_criterion_func=mifs, 
                                     r=r,
                                     data=integer_matrix, 
@@ -41,6 +42,7 @@ class TestFractionMethod(unittest.TestCase):
                                     prev_variables_index=prev_variables_index,
                                     beta=beta)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float)                                    
 
@@ -51,7 +53,7 @@ class TestFractionMethod(unittest.TestCase):
         candidates_index = [0,1,2,6,7,8,9]
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         r = 1
-        selected_feature, criterion_value, cost = fraction_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = fraction_find_best_feature(
                                     j_criterion_func=mrmr, 
                                     r=r,
                                     data=integer_matrix, 
@@ -60,6 +62,7 @@ class TestFractionMethod(unittest.TestCase):
                                     costs=costs, 
                                     prev_variables_index=prev_variable_index)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float) 
 
@@ -70,7 +73,7 @@ class TestFractionMethod(unittest.TestCase):
         candidates_index = [0,1,2,6,7,8,9]
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         r = 1
-        selected_feature, criterion_value, cost = fraction_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = fraction_find_best_feature(
                                     j_criterion_func=jmi, 
                                     r=r,
                                     data=integer_matrix, 
@@ -79,6 +82,7 @@ class TestFractionMethod(unittest.TestCase):
                                     costs=costs, 
                                     prev_variables_index=prev_variable_index)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float) 
 
@@ -90,7 +94,7 @@ class TestFractionMethod(unittest.TestCase):
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         r = 1
         beta=1
-        selected_feature, criterion_value, cost = fraction_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = fraction_find_best_feature(
                                     j_criterion_func=cife, 
                                     r=r,
                                     data=integer_matrix, 
@@ -100,6 +104,7 @@ class TestFractionMethod(unittest.TestCase):
                                     prev_variables_index=prev_variable_index,
                                     beta=beta)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float) 
 
@@ -112,7 +117,7 @@ class TestFractionMethod(unittest.TestCase):
         r = 1
         beta_1 = 1
         beta_2 = 10000
-        _, criterion_value_1, _ = fraction_find_best_feature(
+        _, filter_value_1, criterion_value_1, _ = fraction_find_best_feature(
                                     j_criterion_func=mifs, 
                                     r=r,
                                     data=integer_matrix, 
@@ -121,7 +126,7 @@ class TestFractionMethod(unittest.TestCase):
                                     costs=costs,
                                     prev_variables_index=prev_variables_index,
                                     beta=beta_1)
-        _, criterion_value_2, _ = fraction_find_best_feature(
+        _, filter_value_2, criterion_value_2, _ = fraction_find_best_feature(
                                     j_criterion_func=mifs, 
                                     r=r,
                                     data=integer_matrix, 
@@ -130,6 +135,7 @@ class TestFractionMethod(unittest.TestCase):
                                     costs=costs,
                                     prev_variables_index=prev_variables_index,
                                     beta=beta_2)
+        self.assertNotEqual(filter_value_1,filter_value_2)
         self.assertNotEqual(criterion_value_1,criterion_value_2)
                  
     def test_different_beta_parameter_cife(self):
@@ -141,7 +147,7 @@ class TestFractionMethod(unittest.TestCase):
         r = 1
         beta_1 = 1
         beta_2 = 10000
-        _, criterion_value_1, _ = fraction_find_best_feature(
+        _, filter_value_1, criterion_value_1, _ = fraction_find_best_feature(
                                     j_criterion_func=cife, 
                                     r=r,
                                     data=integer_matrix, 
@@ -150,7 +156,7 @@ class TestFractionMethod(unittest.TestCase):
                                     costs=costs,
                                     prev_variables_index=prev_variables_index,
                                     beta=beta_1)
-        _, criterion_value_2, _ = fraction_find_best_feature(
+        _, filter_value_2, criterion_value_2, _ = fraction_find_best_feature(
                                     j_criterion_func=cife, 
                                     r=r,
                                     data=integer_matrix, 
@@ -159,8 +165,35 @@ class TestFractionMethod(unittest.TestCase):
                                     costs=costs,
                                     prev_variables_index=prev_variables_index,
                                     beta=beta_2)
+        self.assertNotEqual(filter_value_1,filter_value_2)                                    
         self.assertNotEqual(criterion_value_1,criterion_value_2)
 
+    def test_filter_criterion_values(self):
+        np.random.seed(seed=42)
+        integer_matrix = np.random.randint(0,10,(10,10))
+        diverse_target = np.random.randint(0,10,(10))
+        prev_variables_index = [3,4,5]
+        candidates_index = [0,1,2,6,7,8,9]
+        costs = [ 0.1,  0.19, 0.36,  0.96,  0.41,  0.17, 0.36,  0.75,  0.79, 0.99]
+        r_1 = 0
+        r_2 = 10
+        _, filter_value_1, criterion_value_1, _ = fraction_find_best_feature(
+                                    j_criterion_func=jmi, 
+                                    r=r_1,
+                                    data=integer_matrix, 
+                                    target_variable=diverse_target,
+                                    possible_variables_index=candidates_index,
+                                    costs=costs,
+                                    prev_variables_index=prev_variables_index)
+        _, filter_value_2, criterion_value_2, _ = fraction_find_best_feature(
+                                    j_criterion_func=jmi, 
+                                    r=r_2,
+                                    data=integer_matrix, 
+                                    target_variable=diverse_target,
+                                    possible_variables_index=candidates_index,
+                                    costs=costs,
+                                    prev_variables_index=prev_variables_index)
+        assert filter_value_2 > filter_value_1
 
 class TestDifferenceMethod(unittest.TestCase):
     def test_simple_input_mim(self):
@@ -170,7 +203,7 @@ class TestDifferenceMethod(unittest.TestCase):
         candidates_index = [0,1,2,6,7,8,9]
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         lamb = 1
-        selected_feature, criterion_value, cost = difference_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = difference_find_best_feature(
             j_criterion_func=mim, 
             lamb = lamb,
             data=integer_matrix, 
@@ -178,6 +211,7 @@ class TestDifferenceMethod(unittest.TestCase):
             possible_variables_index=candidates_index,
             costs=costs)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float)
 
@@ -189,7 +223,7 @@ class TestDifferenceMethod(unittest.TestCase):
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         lamb = 1
         beta = 1
-        selected_feature, criterion_value, cost = difference_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = difference_find_best_feature(
                                     j_criterion_func=mifs, 
                                     lamb = lamb,
                                     data=integer_matrix, 
@@ -199,6 +233,7 @@ class TestDifferenceMethod(unittest.TestCase):
                                     prev_variables_index=prev_variables_index,
                                     beta=beta)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float)                                    
 
@@ -209,7 +244,7 @@ class TestDifferenceMethod(unittest.TestCase):
         candidates_index = [0,1,2,6,7,8,9]
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         lamb = 1
-        selected_feature, criterion_value, cost = difference_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = difference_find_best_feature(
                                     j_criterion_func=mrmr, 
                                     lamb = lamb,
                                     data=integer_matrix, 
@@ -218,6 +253,7 @@ class TestDifferenceMethod(unittest.TestCase):
                                     costs=costs, 
                                     prev_variables_index=prev_variable_index)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float) 
 
@@ -228,7 +264,7 @@ class TestDifferenceMethod(unittest.TestCase):
         candidates_index = [0,1,2,6,7,8,9]
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         lamb = 1
-        selected_feature, criterion_value, cost = difference_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = difference_find_best_feature(
                                     j_criterion_func=jmi, 
                                     lamb = lamb,
                                     data=integer_matrix, 
@@ -237,6 +273,7 @@ class TestDifferenceMethod(unittest.TestCase):
                                     costs=costs, 
                                     prev_variables_index=prev_variable_index)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float) 
 
@@ -248,7 +285,7 @@ class TestDifferenceMethod(unittest.TestCase):
         costs = [ 1.76,  0.19, -0.36,  0.96,  0.41,  0.17, -0.36,  0.75,  0.79, -1.38]
         lamb = 1
         beta=1
-        selected_feature, criterion_value, cost = difference_find_best_feature(
+        selected_feature, filter_value, criterion_value, cost = difference_find_best_feature(
                                     j_criterion_func=cife, 
                                     lamb = lamb,
                                     data=integer_matrix, 
@@ -258,6 +295,7 @@ class TestDifferenceMethod(unittest.TestCase):
                                     prev_variables_index=prev_variable_index,
                                     beta=beta)
         self.assertIsInstance(selected_feature,int)
+        self.assertIsInstance(filter_value, float)
         self.assertIsInstance(criterion_value, float)
         self.assertIsInstance(cost, float) 
 
@@ -270,7 +308,7 @@ class TestDifferenceMethod(unittest.TestCase):
         lamb = 1
         beta_1 = 1
         beta_2 = 10000
-        _, criterion_value_1, _ = difference_find_best_feature(
+        _, filter_value_1, criterion_value_1, _ = difference_find_best_feature(
                                     j_criterion_func=mifs, 
                                     lamb=lamb,
                                     data=integer_matrix, 
@@ -279,7 +317,7 @@ class TestDifferenceMethod(unittest.TestCase):
                                     costs=costs,
                                     prev_variables_index=prev_variables_index,
                                     beta=beta_1)
-        _, criterion_value_2, _ = difference_find_best_feature(
+        _, filter_value_2, criterion_value_2, _ = difference_find_best_feature(
                                     j_criterion_func=mifs, 
                                     lamb=lamb,
                                     data=integer_matrix, 
@@ -288,6 +326,7 @@ class TestDifferenceMethod(unittest.TestCase):
                                     costs=costs,
                                     prev_variables_index=prev_variables_index,
                                     beta=beta_2)
+        self.assertNotEqual(filter_value_1,filter_value_2)                                          
         self.assertNotEqual(criterion_value_1,criterion_value_2)
                  
     def test_different_beta_parameter_cife(self):
@@ -299,7 +338,7 @@ class TestDifferenceMethod(unittest.TestCase):
         lamb = 1
         beta_1 = 1
         beta_2 = 10000
-        _, criterion_value_1, _ = difference_find_best_feature(
+        _, filter_value_1, criterion_value_1, _ = difference_find_best_feature(
                                     j_criterion_func=cife, 
                                     lamb=lamb,
                                     data=integer_matrix, 
@@ -308,7 +347,7 @@ class TestDifferenceMethod(unittest.TestCase):
                                     costs=costs,
                                     prev_variables_index=prev_variables_index,
                                     beta=beta_1)
-        _, criterion_value_2, _ = difference_find_best_feature(
+        _, filter_value_2, criterion_value_2, _ = difference_find_best_feature(
                                     j_criterion_func=cife, 
                                     lamb=lamb,
                                     data=integer_matrix, 
@@ -317,6 +356,7 @@ class TestDifferenceMethod(unittest.TestCase):
                                     costs=costs,
                                     prev_variables_index=prev_variables_index,
                                     beta=beta_2)
+        self.assertNotEqual(filter_value_1,filter_value_2)                            
         self.assertNotEqual(criterion_value_1,criterion_value_2)
 
 if __name__ == '__main__':
